%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function samples one life cycle path for the market state
% (Sample_market)and one for the technical requirement state 
% (Sample_Requirement).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Sample_Market, Sample_Requirement] = Sample_Path(Lifetime, P_Requirement) 
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Sample Market State
    Sample_Market = zeros(1,Lifetime + 2); % Create Vector for MarketSample 
    
    % Obtain paramters for the market simulation (modeled as a sinus
    % function)
    A = 1; % Amplitude of sinus function 
    P = normrnd(7,1); % Period of sinus function 
    B = (2*pi)/P; 
    Shift = -pi ; % Phase shift in sinus function 
    C = -(Shift)*B;
    D = 10; % Vertical shift in sinus function 
    
    % Simulate market state (continous function)
    t = 0:Lifetime+2;
    drift = 0; 
    for x = 1:(Lifetime + 2)
        MarketRate_Base(1,x) = A*sin(B*t(x)+C) + normrnd(D,0.2) + drift;
        drift = drift +  0.01 + normrnd(0, 0.005*D); % drift in market state
    end
    
    % Discretizise the continous market function into 6 levels 
    for tt = 1:(Lifetime + 2)
        if MarketRate_Base(1,tt) <= D - (2*A/3)
             Sample_Market(1,tt) = 1; % Market state: low (-)
        elseif MarketRate_Base(1,tt) <= D - (A/3)
            Sample_Market(1,tt) = 2; % Market state: low
       elseif MarketRate_Base(1,tt) <= D 
            Sample_Market(1,tt) = 3; % Market state: medium-low  
        elseif MarketRate_Base(1,tt) <= D + (A/3)
            Sample_Market(1,tt) = 4; % Market state: medium-high
        elseif  MarketRate_Base(1,tt) <= D + (2*A/3)
            Sample_Market(1,tt) = 5; % Market state: high
        else %MarketRate_Base(1,tt) <= D + A
            Sample_Market(1,tt) = 6; % Market state: high (+) 
        end
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Sample Requirement State
    Sample_Requirement = zeros(1,Lifetime + 2); % Create Vector for Technical Requirements
    Sample_Requirement(1) = 1; % Know the market state when the vessels first operates 

    for tt = 2:Lifetime + 2
          if Sample_Requirement(tt-1) == 1 && tt > 9 
            Sample_Requirement(tt) = 2; % Medium technical requirements
          else
            r = rand; % Pick a random number in [0,1]
            Sample_Requirement(tt) = sum(r >= cumsum([0,P_Requirement(Sample_Requirement(tt-1),1),P_Requirement(Sample_Requirement(tt-1),2),P_Requirement(Sample_Requirement(tt-1),3)])); % Find next market state
          end
    end
end